<?php

/**
 * WebService Miriade.ephemcc - ephemerides de position des SSO
 *   NameSpace : http://vo.imcce.fr/webservices/miriade/
 *   WSDL      : http://vo.imcce.fr/webservices/miriade/miriade.wsdl
 *   Method    : ephemcc
 *   Parameters:  name     -> Number or name or designation of the target (with or not leading code 'a', 'p', 's', 'c')
 *                type     -> Optionnal input which allows to define the type of the target (aster, planet, satel, comet)
 *                ep       -> Starting date of ephemeris computation, expressed as Julian day or ISODate with or without the 'T'
 *                nbd      -> Number of date of ephemeris to compute
 *                step     -> Step of increment expressed in (d)ays or (h)ours or (m)inutes or (s)econds
 *                tscale   -> Ephemeris time scale
 *                observer -> Location of the observer (500: geocenter (def.), ...)
 *                theory   -> Planetary theory to use for the calculation (INPOP (def.) or DE405)  
 *                teph     -> Type of ephemeris (1:astrometric J2000, 2:apparent of the date, 3: mean of the date, 4: mean J2000)
 *                tcoor    -> Type of coordinates (1: spherical, 2: state vector, 3: ...)
 *                rplane   -> Reference plane (1:equator (def.), 2: ecliptic)
 *                mime     -> Output format ('votable' or 'text' or 'html')
 *                output   -> [for future use]
 *                extrap   -> Number of decimals of the results (def. 0)
 *   Response  : Position ephemeris of the requested SSO
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & F.Vachier (IMCCE/OBSPM) <fv@imcce.fr>
 * @copyright (C) 2005-2013, IMCCE
 * @since PHP5
 * @version 2.0
 */

// Client's ID
$from = 'DemoClient';

// Parametres du service
$param = array(
   'name'     => 'http://vo.imcce.fr/webservices/miriade/clients/cli_php/targets.dat',
   'type'     => "",
   'epoch'    => 'http://vo.imcce.fr/webservices/miriade/clients/cli_php/epochs.dat',
   'nbd'      => 5,
   'step'     => '1d',
   'tscale'   => 'UTC',
   'observer' => '500',
   'theory'   => 'INPOP',
   'teph'     => 1,
   'tcoor'    => 1,
   'rplane'   => 1,
   'mime'     => 'text',
   'output'   => '',
   'extrap'   => 0
);

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);

// Namespace et WSDL du service
$uri     = 'http://vo.imcce.fr/webservices/miriade';
$wsdl    = 'miriade.wsdl';
$uriwsdl = $uri."/".$wsdl;

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($uriwsdl, array('exceptions'=>1, 'soap_version'=>"SOAP_1_2"));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('ephemcc',array($param));
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    echo "# Flag  : ".$response->flag."\n";
    echo "# Ticket: ".$response->ticket."\n";
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; };
  }
  else if ($param['mime'] == 'text/csv')
  {
    header("Content-Type: text/plain");
    echo "# Ticket: ".$response->ticket." (flag=".$response->flag.")\n";
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
}
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
