<?php

/**
 * WebService Miriade.rts - calcul des levers, passages et couchers des SSO
 *   NameSpace : http://vo.imcce.fr/webservices/miriade/
 *   WSDL      : http://vo.imcce.fr/webservices/miriade/miriade.wsdl
 *   Method    : rts
 *   Parameters:  body  -> List of targets, separated by a comma (1..8: Mercury to Neptune, 10: Moon, 11: Sun)
 *                epoch -> Julian day of the starting epoch (expressed at noon)
 *                nbd   -> Number of day of computation (<731)
 *                long  -> Longitude of observer place (in decimal degrees, negative toward East)
 *                lat   -> Latitude of observer place (in decimal degrees, negative toward South)
 *                mime  -> Output format ('votable' or 'text' or 'html')
 *   Response  : Rise, transit and set of the requested targets
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & J.Normand (OBSPM) <jonathan.normand@obspm.fr>
 * @copyright (C) 2005-2013, IMCCE/OBSPM
 * @since PHP5
 * @version 2.0
 */

// Definition des parametres
$body   = '11,10,4';   // Liste des corps separes par une virgule, avec 1..8: Mercure a Neptune, 10: Lune, 11: Soleil 
$epoch  = 'now';       // Jour julien de la date de ou du debut de la periode consideree (JD a 12h)
$nbd    = 1;           // Nombre de dates de calcul (<731)
$long   = -2.3511111;  // longitude du lieu exprimee en degres decimaux
$lat    = 48.8566667;  // latitude du lieu exprimee en degres decimaux
$mime   = 'text';      // Format de sortie (votable ou html ou text) 
$extrap = 1;           // Nombre de chiffres significatifs
$tz     = 0;

// Definition de l'entete
$from = 'DemoClient';  // Nom ou designation du client pour trace dans les logs

// Parametres du service
$param = array(
   'body'      => $body,
   'epoch'     => $epoch,
   'nbd'       => $nbd,
   'longitude' => $long,
   'latitude'  => $lat,
   'tz'        => $tz,
   'mime'      => $mime,
   'extrap'    => $extrap
);

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);

// Namespace et WSDL du service
$uri = 'http://vo.imcce.fr/webservices/miriade';
$wsdl = $uri.'/miriade.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($wsdl, array('exceptions'=>1, 'soap_version'=>"SOAP_1_2"));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('rts',array($param));
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    // flag = -1 (error) ou 0 (warning) ou 1 (ok)
    echo "# Flag  : ".$response->flag."\n";
    echo "# Ticket: ".$response->ticket."\n";
    // result contient les resultats sous la forme d'une chaine separee par des ';'
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
}
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
