<?php

/**
 * WebService ViSiON - HTTP client
 *   NameSpace : http://vo.imcce.fr/webservices/miriade
 *   WSDL      : http://vo.imcce.fr/webservices/miriade/miriade.wsdl
 *   Methods   : vision
 *   Protocol  : HTTP/POST + SOAP
 *   Request   : vision_query.php[?<param>=<valeur>]
 *               with param :
 *                  -target   -> Celestial object name or designation (mandatory)
 *                  -epoch    -> Requested starting epoch (opt., defautl is now)
 *                  -nbd      -> Number of dates (opt., default is 1)
 *                  -step     -> Step size of the computation (opt., default is 1d) 
 *                  -observer -> IAU code of the location of the observer (opt., default is 007)
 *                  -mime     -> Mime type of the response: 'votable' | 'html' | 'text' (opt., default is votable)
 *               Additional Parameters (header):
 *                  -from     -> name or designation of the calling service 
 *   Response  : Object which contains a flag, a ticket and the result
 * 
 * @author J. Berthier (IMCCE/OBSPM) <berthier@imcce.fr> & B. Carry (ESAC) <benoit.carry@esac.int>
 * @copyright (C) 2010-2013, IMCCE
 * @since PHP5
 * @version 1.0
 */

// Definition des parametres
$target   = 'a:Ceres,p:Jupiter'; // Celestial object name or designation (mandatory)
$epoch    = '2455979.0';         // Requested starting epoch (JD)
$nbd      = 1;                   // Number of dates (opt., default is 1)
$step     = 1;                   // Step size of the computation (opt., default is 1d) 
$observer = '586';               // IAU code of the location of the observer (opt., default is 007)
$mime     = 'pdf';               // Mime type of the response: 'votable' | 'html' | 'pdf' (opt., default is votable)

// Definition de l'entete
$from = 'DemoClient';            // Nom ou designation du client pour trace dans les logs

// Parametres du service
$param = array( 'name'     => $target,
                'epoch'    => $epoch, 
                'nbd'      => $nbd,
                'step'     => $step,
                'observer' => $observer,
                'mime'     => $mime
);

// Mise en cache ou non du WSDL du service
ini_set('soap.wsdl_cache_enabled', 1);

// Namespace et WSDL du service
$uri = 'http://vo.imcce.fr/webservices/miriade';
$wsdl = $uri.'/miriade.wsdl';

// Execution de la requete
try 
{
  // Instantiation du client
  $client = new SoapClient($wsdl, array('exceptions'=>1, 'soap_version'=>"SOAP_1_2"));
  // Parametres de l'entete SOAP
  $header = array('from'=>$from, 'hostip'=>'');
  // Construction de l'entete SOAP
  $client->__setSoapHeaders(array(new SOAPHeader($uri, 'clientID', $header)));
  // Appel de la methode
  $response = $client->__soapCall('vision',array($param));
  // Affichage du resultat
  if ($param['mime'] == 'text')
  {
    header("Content-Type: text/plain");
    // flag = -1 (error) ou 0 (warning) ou 1 (ok)
    echo "# Flag  : ".$response->flag."\n";
    echo "# Ticket: ".$response->ticket."\n";
    // result contient les resultats sous la forme d'une chaine separee par des ';'
    $res = explode(';', $response->result);
    $nbr = count($res);
    $newkey = array_keys($res);
    for ($i=0; $i<$nbr; $i++) { echo $res[$newkey[$i]],"\n"; };
  }
  else
  {
    header("Content-Type: text/xml");
    echo $response->result."\n";
  }
}
catch (SoapFault $fault) 
{
  trigger_error("SOAP Fault: {$fault->getTraceAsString()} (faultcode: {$fault->faultcode}, faultstring: {$fault->faultstring})", E_USER_ERROR);
}

?>
